@@ -1,5 +1,4 @@
 {-# LANGUAGE QuasiQuotes #-}
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 -- | Provides a dummy authentication module that simply lets a user specify
 -- his/her identifier. This is not intended for real world use, just for
@@ -8,13 +7,11 @@ module Yesod.Auth.Dummy
     ( authDummy
     ) where
 
-#include "qq.h"
-
 import Yesod.Auth
 import Yesod.Form (runInputPost, textField, ireq)
 import Yesod.Handler (notFound)
 import Text.Hamlet (hamlet)
-import Yesod.Widget (addHamlet)
+import Yesod.Widget (toWidget)
 
 authDummy :: YesodAuth m => AuthPlugin m
 authDummy =
@@ -26,9 +23,9 @@ authDummy =
     dispatch _ _ = notFound
     url = PluginR "dummy" []
     login authToMaster =
-        addHamlet [QQ(hamlet)|
+        toWidget [hamlet|
 <form method="post" action="@{authToMaster url}">
-    \Your new identifier is: 
+    Your new identifier is: #
     <input type="text" name="ident">
     <input type="submit" value="Dummy Login">
 |]
